#!/usr/bin/env ruby

# Xcode auto-versioning script for Subversion by Axel Andersson
# Updated for git by Marcus S. Zarra and Matt Long
# Converted to ruby by Abizer Nasir
# Bug fix for path and write hash with time/date to CFBundleGetInfoString by Mark Moore
# Appends the git sha to the version number set in Xcode.
# see http://www.stompy.org/2008/08/14/xcode-and-git-another-build-script/ for more details

def injectVersion(info_file, key, sha, tstr)

    # Get the version info from the source Info.plist file
    # If the script has already been run we need to remove the git sha
    # from the bundle’s Info.plist.
    f = File.open(info_file, "r").read
    re = /([\t ]+<key>#{Regexp.quote(key)}<\/key>\n[\t ]+<string>)(.*?)(<\/string>)/
    f =~ re
    open = $1
    orig_version = $2
    close = $3

    # If the git hash has not already been injected into the Info.plist, this will set version to nil
    version = nil
    if ($2)
        version = $2.sub!(/\s*Build:.*/, '')
    end
    if (!version)
      version = orig_version
    end
    version.chomp
    if (version != "")
        version = version + " "
    end

    # Inject the git hash into the bundle’s Info.plist
    sub = "#{open}#{version}Build:#{sha} #{tstr}#{close}"
    f.gsub!(re, sub)
    File.open(info_file, "w") { |file| file.write(f) }

end


git_path = `/usr/bin/which git`.chomp
if git_path == ""
  puts "Path to git not found"
  exit
end

command_line = git_path + " rev-parse --short HEAD"
sha = `#{command_line}`.chomp

# Get the date and time.
time = Time.new
tstr = time.strftime("%Y-%m-%d/%H:%M")

info_file = ENV['BUILT_PRODUCTS_DIR'] + "/" + ENV['INFOPLIST_PATH']

injectVersion(info_file, "CFBundleGetInfoString", sha, tstr)
injectVersion(info_file, "AntelopeAudioDriverVersion", sha, tstr)

